@@ -1,7 +1,7 @@
+from .absorption import *
 from .conversions import *
 from .decibels import *
 from .metrics import *
 from .spectra import *
 from .sources import *
-from .room import *
-from .boundaries import *
\ No newline at end of file
+from .room import *
\ No newline at end of file
