@@ -113,7 +113,10 @@ def define_loudspeaker_array(num_speakers,cone_diameter,cone_separation,
     return positions, strengths, phases, cone_positions
 
 """
-Modeling a moving-coil loudspeaker
+Modeling a moving-coil loudspeaker. This is not fully trusted, but gives some results as expected based
+on class notes in BYU PHSCS 660, Winter 2022. If you need definitive results, you should write your own
+code for find a trusted solver. This is intended (and only trusted) to give you an idea of what the 
+different parameters do.
 """
 
 def moving_coil_loudspeaker(Cms = 1.0e-4, # m/N (Suspension Mechanical Compliance)
@@ -126,7 +129,7 @@ def moving_coil_loudspeaker(Cms = 1.0e-4, # m/N (Suspension Mechanical Complianc
                             Rg = 0, # Ohms (Voltage Source Internal Resistance)
                             eg = 1, # Volts (Input voltage)
                             c = 343, # m/s (Speed of sound)
-                            show_TVC = False, # whether to show the TVC plot
+                            show_TVR = True, # whether to show the TVR plot
                             show_Analysis_Plots = False, # Whether to show impedance plots
                             r = 1, # Distance at which to calculate everything
                             f = np.logspace(0,3,1000)
@@ -189,7 +192,7 @@ def moving_coil_loudspeaker(Cms = 1.0e-4, # m/N (Suspension Mechanical Complianc
         plt.ylabel("Value")
         plt.title("Far-field Pressure")
 
-    if show_TVC:
+    if show_TVR:
         p = np.abs(u_d)/1.0 * ka * np.sqrt(rho_0*c/(4*np.pi))
 
         # Accession to inertia (equation 4.826)
@@ -197,13 +200,13 @@ def moving_coil_loudspeaker(Cms = 1.0e-4, # m/N (Suspension Mechanical Complianc
         omega_0 = np.sqrt(1/(Cms*(Mmd + 2*Mmr)))
         f_0 = omega_0/(2*np.pi)
 
-        TVC = 20*np.log10((p/eg)/20e-6)
+        TVR = 20*np.log10((p/eg)/20e-6)
 
         plt.figure()
-        plt.semilogx(f,TVC,label = "TVC")
-        plt.semilogx([1,2],[min(TVC),12 + min(TVC)],label = "12 dB / Octave",linestyle = "--")
-        plt.vlines(f_0,ymin = min(TVC), ymax = max(TVC),label = "$f_0$",color = "red",linestyle = "--")
-        plt.vlines(10*f_0,ymin = min(TVC), ymax = max(TVC),label = "$10*f_0$",color = "purple",linestyle = "--")
+        plt.semilogx(f,TVR,label = "TVR")
+        plt.semilogx([1,2],[min(TVR),12 + min(TVR)],label = "12 dB / Octave",linestyle = "--")
+        plt.vlines(f_0,ymin = min(TVR), ymax = max(TVR),label = "$f_0$",color = "red",linestyle = "--")
+        plt.vlines(10*f_0,ymin = min(TVR), ymax = max(TVR),label = "$10*f_0$",color = "purple",linestyle = "--")
         plt.xlabel("Frequency (Hz)")
         plt.ylabel("$\hat{p}/\hat{e}_g$")
         plt.title("Transmitting Voltage Response")
